==> nextcloud-22.2.8.tgz: nextcloud/apps/notifications/l10n/ja.js <==
OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "こんにちは %s さん",
    "Hello %s," : "こんにちは %s さん、",
    "Admin notifications" : "管理者の通知",
    "Notifications" : "通知",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "このアプリは、Nextcloudで利用可能な通知APIのバックエンドとフロントエンドを提供します。",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "このアプリはNextcloudで利用可能な通知APIのバックエンドとフロントエンドを提供します。\n\t\tAPIは、Web UI内のユーザーに通知したり、クライアントを同期したりする際、他のアプリケーションによって使用されます。例をいくつか示します。\n\n📬連携ファイル共有: 新しいリモート共有を受け取ったとき\n\n📑コメント: 他のユーザーがファイルのコメントにあなたの名前を挙げたとき\n\n🚢更新通知: アプリまたはnextcloud自体に利用可能な更新がきたとき\n\n📣 アナウンスセンター: アナウンスが管理者によって投稿されたとき",
    "Dismiss all notifications" : "全ての通知を閉じる",
    "Requesting browser permissions to show notifications" : "通知を表示するためにブラウザーの権限を要求中",
    "No notifications" : "通知はありません",
    "Failed to dismiss all notifications" : "すべての通知を破棄できませんでした",
    "Failed to perform action" : "アクションの実行に失敗",
    "Dismiss" : "閉じる",
    "seconds ago" : "数秒前",
    "Failed to dismiss notification" : "通知の却下に失敗しました",
    "in {path}" : "{path}に",
    "You need to set up your email address before you can receive notification emails." : "通知メールを受け取る前にメールアドレスを設定してください。",
    "Send email reminders about unhandled notifications after:" : "未処理の通知に関するリマインダーメールを設定時間後に送る：",
    "Play sound when a new notification arrives" : "新着通知時に音を鳴らす",
    "Play sound when a call started (requires Nextcloud Talk)" : "通話開始時に音を鳴らす（要 Nextcloud Talk）",
    "Never" : "なし",
    "1 hour" : "1時間",
    "3 hours" : "3時間",
    "1 day" : "1日",
    "1 week" : "1週間",
    "Your settings have been updated." : "設定を更新しました。",
    "An error occurred while updating your settings." : "設定の更新中にエラーが発生しました。"
},
"nplurals=1; plural=0;");

==> nextcloud-23.0.9.tgz: nextcloud/apps/notifications/l10n/ja.js <==
OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "こんにちは %s さん",
    "Hello %s," : "こんにちは %s さん、",
    "_New notification for %s_::_%n new notifications for %s_" : ["%sの新着通知が%n件あります"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["%sに関する新着通知が%n件あります"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "これらのメールの頻度または完全に無効化することは<a href=\"%s\">設定</a>から行えます。",
    "You can change the frequency of these emails or disable them in the settings: %s" : "これらのメールの頻度または完全に無効化することは設定の次から行えます: %s",
    "Admin notifications" : "管理者の通知",
    "Notifications" : "通知",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "このアプリは、Nextcloudで利用可能な通知APIのバックエンドとフロントエンドを提供します。",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "このアプリはNextcloudで利用可能な通知APIのバックエンドとフロントエンドを提供します。\n\t\tAPIは、Web UI内のユーザーに通知したり、クライアントを同期したりする際、他のアプリケーションによって使用されます。例をいくつか示します。\n\n📬連携ファイル共有: 新しいリモート共有を受け取ったとき\n\n📑コメント: 他のユーザーがファイルのコメントにあなたの名前を挙げたとき\n\n🚢更新通知: アプリまたはnextcloud自体に利用可能な更新がきたとき\n\n📣 アナウンスセンター: アナウンスが管理者によって投稿されたとき",
    "Failed to perform action" : "アクションの実行に失敗",
    "Dismiss" : "閉じる",
    "seconds ago" : "数秒前",
    "Failed to dismiss notification" : "通知の却下に失敗しました",
    "in {path}" : "{path}に",
    "Dismiss all notifications" : "全ての通知を閉じる",
    "Requesting browser permissions to show notifications" : "通知を表示するためにブラウザーの権限を要求中",
    "No notifications" : "通知はありません",
    "Failed to dismiss all notifications" : "すべての通知を破棄できませんでした",
    "You need to set up your email address before you can receive notification emails." : "通知メールを受け取る前にメールアドレスを設定してください。",
    "Send email reminders about unhandled notifications after:" : "未処理の通知に関するリマインダーメールを設定時間後に送る：",
    "Play sound when a new notification arrives" : "新着通知時に音を鳴らす",
    "Play sound when a call started (requires Nextcloud Talk)" : "通話開始時に音を鳴らす（要 Nextcloud Talk）",
    "Never" : "なし",
    "1 hour" : "1時間",
    "3 hours" : "3時間",
    "1 day" : "1日",
    "1 week" : "1週間",
    "Your settings have been updated." : "設定を更新しました。",
    "An error occurred while updating your settings." : "設定の更新中にエラーが発生しました。"
},
"nplurals=1; plural=0;");
